@@ -654,10 +654,7 @@ cd_player_eject (GooPlayer *player)
 	destroy_pipeline (player_cd, TRUE);
 
 	cdrom_state = goo_cdrom_get_state (priv->cdrom);
-	if (cdrom_state == GOO_CDROM_STATE_TRAY_OPEN)
-		result = goo_cdrom_close_tray (priv->cdrom);
-	else
-		result = goo_cdrom_eject (priv->cdrom);
+	result = goo_cdrom_eject (priv->cdrom);
 
 	if (!result)
 		goo_player_set_error (player, goo_cdrom_get_error (priv->cdrom));
@@ -758,6 +755,7 @@ cdrom_state_changed_cb (GooCdrom  *cdrom,
 	case GOO_CDROM_STATE_TRAY_OPEN:
 		state = "TRAY_OPEN";
 		message = _("Tray open");
+		message = _("No disc");
 		break;
 	case GOO_CDROM_STATE_NO_DISC:
 		state = "NO_DISC";
